export declare type Location = {
    start: number;
    end: number;
};
export declare type TextStatement = {
    type: 'TEXT';
    loc: Location;
    value: string;
};
export declare type CommentStatement = {
    type: 'COMMENT';
    loc: Location;
    value: string;
};
export declare type ExpressionStatement = {
    type: 'EXPRESSION';
    loc: Location;
    path: string;
    params: (ExpressionStatement | LiteralStatement)[];
};
export declare type MustacheStatement = {
    type: 'MUSTACHE';
    loc: Location;
    expression: ExpressionStatement | LiteralStatement;
};
export declare type BlockStatement = {
    type: 'BLOCK';
    loc: Location;
    isNegated: boolean;
    isNested?: boolean;
    expression: ExpressionStatement;
    statements: Statement[];
    elseStatements?: Statement[];
};
export declare type TemplateStatement = {
    type: 'TEMPLATE';
    loc: Location;
    version: number;
    statements: Statement[];
};
export declare type LiteralStatement = {
    type: 'LITERAL';
    loc: Location;
    value: string | number | boolean | null | undefined;
};
export declare type Statement = TextStatement | LiteralStatement | CommentStatement | BlockStatement | ExpressionStatement | MustacheStatement | TemplateStatement;
